from django.contrib.syndication.views import Feed
from django.contrib.sites.models import Site
from django.core.urlresolvers import reverse
from models import Actuality
from django.utils.translation import ugettext_lazy as _

currentSite = Site.objects.get_current()

class ActualitiesFeed(Feed):
    title = currentSite.name
    description = _(u"%s's actualities") % currentSite.name

    def link(self):
        return reverse('actualities.views.list')

    def items(self):
        return Actuality.objects.published()[:10]

    def item_title(self, item):
        return item.title

    def item_description(self, item):
        return item.text

    def item_pubdate(self, item):
        return item.published_at
        



from django.conf.urls.defaults import *
from actualities.feeds import ActualitiesFeed

urlpatterns = patterns('',
   url(r'^$', 'actualities.views.list'),
   url(r'^rss/$', ActualitiesFeed(), name="actualities_rss"),
   url(r'^(?P<year>[\d]{4})/(?P<month>[\d]{2})/(?P<day>[\d]{2})/(?P<slug>[\w\-]+)/$', 'actualities.views.actuality'),
)


from setuptools import setup, find_packages

setup(
    name = "django-actualities",
    version = "0.1.0",
    description = """
    A django blog app
    """,
    author = "Platypus Creation",
    author_email = "contact@platypus-creation.com",
    url = "https://github.com/platypus-creation/django-actualities",
    packages = find_packages(),
    include_package_data=True,
    install_requires = [
        'django-taggit==0.9.3',
    ],
)
